pub fn validate(
config: &SearchConfig,
dataset: &Dataset,
) -> Result<(), SearchError>Expand description
Checks the dataset and the parameters before a search starts.
pub fn validate(
config: &SearchConfig,
dataset: &Dataset,
) -> Result<(), SearchError>Checks the dataset and the parameters before a search starts.