BudgetSchedule

Trait BudgetSchedule 

pub trait BudgetSchedule: Send {
    // Required methods
    fn first(&mut self) -> Budget;
    fn next(&mut self, last: &PassReport) -> Option<Budget>;
}
Produces the budget of each pass.

Required Methods

fn first(&mut self) -> Budget

The budget of the first pass.

fn next(&mut self, last: &PassReport) -> Option<Budget>

The budget of the next pass, given what the last one did; None when there is nothing larger to try, which ends the search.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors